@@ -28,7 +28,7 @@ arma::mat to_indicator_matrix(arma::vec v) {
     auto m {v.max()};
     arma::mat A(n, m);
     for (size_t i {0}; i < n; i++) {
-        A(i, v[i]-1.0) = 1.0;
+        A(i, v(i)-1.0) = 1.0;
     }
     return A;
 }
